==> img0ch-3.1.1.tar.bz2: img0ch/_template/zeromin2/vthread_load_user.cs <==
<?cs include:"zeromin2/header.cs" ?>

<?cs include:"zeromin2/menu_bbs.cs" ?>

<?cs include:"zeromin2/vthread_side_menu.cs" ?>

<div id="main">

<form id="vthreadUserContainerForm" action="<?cs var:html_escape(ZerominScript) ?>" method="post">

<div id="navhead">
  <hr />
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">掲示板管理</a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_index&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false"><?cs var:html_escape(BBS_TITLE) ?></a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=thread&amp;method=load&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;key=<?cs var:html_escape(KEY) ?>&amp;option=l50&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false"><?cs var:html_escape(Subject) ?></a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=vthread&amp;method=load_user&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;key=<?cs var:html_escape(KEY) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">仮想スレッド内のユーザ</a><br />
</div>

<h1>仮想スレッド内のユーザ</h1>

<?cs if:Code0 ?>
<?cs if:Done_vthread_save_user ?><div class="noticeSuccess" id="notify"><p>ユーザ情報を更新しました</p></div><?cs /if ?>
<?cs if:Done_vthread_remove_user ?><div class="noticeSuccess" id="notify"><p>ユーザを削除しました</p></div><?cs /if ?>
<?cs if:Done_vthread_load_user ?><div class="" id="notify"></div><?cs /if ?>
<?cs else ?>
<?cs if:Code1 ?><div class="noticeFailed" id="notify"><p>実行権限がありません</p></div><?cs /if ?>
<?cs /if ?>

<p>
チェックボックスにチェックを入れ、「削除」でユーザーの削除が出来ます。<br />
<a href="<?cs var:html_escape(ZerominScript) ?>?class=vthread&amp;method=create_user&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;key=<?cs var:html_escape(KEY) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">仮想スレッドユーザの新規作成はこちらから行ってください</a>
</p>

<p>
<select name="method">
  <option value="load_user">一覧表示</option>
  <option value="remove_user">削除</option>
</select>
<input type="submit" value="実行" />
</p>

<table class="simple">
  <thead>
  <tr>
    <th><input type="checkbox" name="" value="" onclick="Zeromin2.selectAllCheckbox( this, 'id' )" /></th>
    <th>ユーザ名</th>
    <th>権限</th>
  </tr>
  </thead>
  <tbody>
  <?cs each:item = Users ?>
  <tr>
    <td><input type="checkbox" name="id" value="<?cs var:html_escape(id) ?>" /></td>
    <td><a href="<?cs var:html_escape(ZerominScript) ?>?class=vthread&amp;method=edit_user&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;key=<?cs var:html_escape(KEY) ?>&amp;id=<?cs var:id ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false"><?cs var:name ?></a></td>
    <td>
      <select name="privilege" multiple="multiple">
        <option value="1"<?cs if:administrator ?> selected="selected"<?cs /if ?>>仮想スレッド管理特権</option>
        <option value="2"<?cs if:can_remove_res ?> selected="selected"<?cs /if ?>>スレッド内のレスの削除</option>
        <option value="4"<?cs if:can_remove_file ?> selected="selected"<?cs /if ?>>スレッド内のレスの添付ファイル削除</option>
        <option value="8"<?cs if:can_edit_res ?> selected="selected"<?cs /if ?>>スレッド内のレス編集</option>
        <option value="16"<?cs if:can_stop_thread ?> selected="selected"<?cs /if ?>>スレッドの停止</option>
        <option value="32"<?cs if:can_restart_thread ?> selected="selected"<?cs /if ?>>スレッドの再開</option>
        <option value="64"<?cs if:can_control_access ?> selected="selected"<?cs /if ?>>スレッド内のアクセス制限</option>
        <option value="128"<?cs if:can_edit_ngword ?> selected="selected"<?cs /if ?>>スレッド内のNGワード制限</option>
        <option value="256"<?cs if:can_change_setting ?> selected="selected"<?cs /if ?>>スレッド内の独自設定変更</option>
        <option value="512"<?cs if:can_add_user ?> selected="selected"<?cs /if ?>>スレッド内のユーザ追加</option>
        <option value="1024"<?cs if:can_remove_user ?> selected="selected"<?cs /if ?>>スレッド内のユーザ削除</option>
        <option value="2048"<?cs if:can_inherit_thread ?> selected="selected"<?cs /if ?>>仮想スレッドの設定継承</option>
      </select>
    </td>
  </tr>
  <?cs /each ?>
  </tbody>
</table>

<div class="formFooter">
<input type="hidden" name="<?cs var:html_escape(SessionName) ?>" value="<?cs var:html_escape(Session) ?>" />
<input type="hidden" name="token" value="<?cs var:html_escape(Token) ?>" />
<input type="hidden" name="class" value="vthread" />
<input type="hidden" name="method" value="save_user" />
<input type="hidden" name="bbs" value="<?cs var:html_escape(BBS) ?>" />
<input type="hidden" name="key" value="<?cs var:html_escape(KEY) ?>" />
<input type="hidden" name="OK" value="load_user" />
<input type="hidden" name="NG" value="load_user" />
<br id="endmain" />
</div>

</form>

</div>

<?cs include:"zeromin2/footer.cs" ?>

==> img0ch-3.1.10.tar.bz2: img0ch/_template/zeromin2/vthread_load_user.cs <==
<?cs include:"zeromin2/header.cs" ?>

<?cs include:"zeromin2/menu_bbs.cs" ?>

<?cs include:"zeromin2/vthread_side_menu.cs" ?>

<div id="main">

<form id="vthreadUserContainerForm" action="<?cs var:html_escape(ZerominScript) ?>" method="post">

<div id="navhead">
  <hr />
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">掲示板管理</a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_index&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false"><?cs var:html_escape(BBS_TITLE) ?></a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=thread&amp;method=load&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;key=<?cs var:html_escape(KEY) ?>&amp;option=l50&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false"><?cs var:Subject ?></a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=vthread&amp;method=load_user&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;key=<?cs var:html_escape(KEY) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">仮想スレッド内のユーザ</a><br />
</div>

<h1>仮想スレッド内のユーザ</h1>

<?cs if:Code0 ?>
<?cs if:Done_vthread_save_user ?><div class="noticeSuccess" id="notify"><p>ユーザ情報を更新しました</p></div><?cs /if ?>
<?cs if:Done_vthread_remove_user ?><div class="noticeSuccess" id="notify"><p>ユーザを削除しました</p></div><?cs /if ?>
<?cs if:Done_vthread_load_user ?><div class="" id="notify"></div><?cs /if ?>
<?cs else ?>
<?cs if:Code1 ?><div class="noticeFailed" id="notify"><p>実行権限がありません</p></div><?cs /if ?>
<?cs /if ?>

<p>
チェックボックスにチェックを入れ、「削除」でユーザーの削除が出来ます。<br />
<a href="<?cs var:html_escape(ZerominScript) ?>?class=vthread&amp;method=create_user&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;key=<?cs var:html_escape(KEY) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">仮想スレッドユーザの新規作成はこちらから行ってください</a>
</p>

<p>
<select name="method">
  <option value="load_user">一覧表示</option>
  <option value="remove_user">削除</option>
</select>
<input type="submit" value="実行" />
</p>

<table class="simple">
  <thead>
  <tr>
    <th><input type="checkbox" name="" value="" onclick="Zeromin2.selectAllCheckbox( this, 'id' )" /></th>
    <th>ユーザ名</th>
    <th>権限</th>
  </tr>
  </thead>
  <tbody>
  <?cs each:item = Users ?>
  <tr>
    <td><input type="checkbox" name="id" value="<?cs var:html_escape(id) ?>" /></td>
    <td><a href="<?cs var:html_escape(ZerominScript) ?>?class=vthread&amp;method=edit_user&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;key=<?cs var:html_escape(KEY) ?>&amp;id=<?cs var:id ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false"><?cs var:name ?></a></td>
    <td>
      <select name="privilege" multiple="multiple">
        <option value="1"<?cs if:administrator ?> selected="selected"<?cs /if ?>>仮想スレッド管理特権</option>
        <option value="2"<?cs if:can_remove_res ?> selected="selected"<?cs /if ?>>スレッド内のレスの削除</option>
        <option value="4"<?cs if:can_remove_file ?> selected="selected"<?cs /if ?>>スレッド内のレスの添付ファイル削除</option>
        <option value="8"<?cs if:can_edit_res ?> selected="selected"<?cs /if ?>>スレッド内のレス編集</option>
        <option value="16"<?cs if:can_stop_thread ?> selected="selected"<?cs /if ?>>スレッドの停止</option>
        <option value="32"<?cs if:can_restart_thread ?> selected="selected"<?cs /if ?>>スレッドの再開</option>
        <option value="64"<?cs if:can_control_access ?> selected="selected"<?cs /if ?>>スレッド内のアクセス制限</option>
        <option value="128"<?cs if:can_edit_ngword ?> selected="selected"<?cs /if ?>>スレッド内のNGワード制限</option>
        <option value="256"<?cs if:can_change_setting ?> selected="selected"<?cs /if ?>>スレッド内の独自設定変更</option>
        <option value="512"<?cs if:can_add_user ?> selected="selected"<?cs /if ?>>スレッド内のユーザ追加</option>
        <option value="1024"<?cs if:can_remove_user ?> selected="selected"<?cs /if ?>>スレッド内のユーザ削除</option>
        <option value="2048"<?cs if:can_inherit_thread ?> selected="selected"<?cs /if ?>>仮想スレッドの設定継承</option>
      </select>
    </td>
  </tr>
  <?cs /each ?>
  </tbody>
</table>

<div class="formFooter">
<input type="hidden" name="<?cs var:html_escape(SessionName) ?>" value="<?cs var:html_escape(Session) ?>" />
<input type="hidden" name="token" value="<?cs var:html_escape(Token) ?>" />
<input type="hidden" name="class" value="vthread" />
<input type="hidden" name="method" value="save_user" />
<input type="hidden" name="bbs" value="<?cs var:html_escape(BBS) ?>" />
<input type="hidden" name="key" value="<?cs var:html_escape(KEY) ?>" />
<input type="hidden" name="OK" value="load_user" />
<input type="hidden" name="NG" value="load_user" />
<br id="endmain" />
</div>

</form>

</div>

<?cs include:"zeromin2/footer.cs" ?>
